BX.namespace('JsAppExample');

/**
 * Пример JS-приложения на основе REST API и UI-библиотеки.
 * @constructor
 */
BX.JsAppExample.Application = function () {
    this.templateCache = {};
    this.contentPane = BX.findChildByClassName(BX('workarea'), 'workarea-content-paddings', true);
};

BX.JsAppExample.Application.prototype = {

    /**
     * Запускает приложение.
     */
    run: function () {
        this._displayProfile();
    },

    /**
     * Выводит информацию о текущем пользователе на странице.
     * Информацию о пользователе получает с помощью REST-метода "profile".
     * Для шаблонизации использует Mustache. Шаблон - либо со страницы (script), либо загружает с сервера.
     * @private
     */
    _displayProfile: function () {

        var self = this;

        var profile = null;
        var profileTemplate = null;

        var promise = new BX.Promise();

        promise.then(function () {
            return BX.rest.callMethod(
                'profile',
                null
            );
        }).then(function (restResult) {
            profile = restResult.data();

            return self._getTemplate('/local/js/profile.mustache');
            //return self._getTemplateFromPage('profileTemplate');
        }).then(function (template) {
            profileTemplate = template;

            self.contentPane.innerHTML = Mustache.render(
                profileTemplate,
                {
                    Loc: BX.message,
                    profile: profile
                }
            );
        });

        promise.fulfill();
    },

    /**
     * Возвращает шаблон Mustache по указанному URL.
     * Если шаблон уже запрашивался, не делает запрос к серверу.
     * @param {string} templateUrl
     * @return {BX.Promise|string}
     * @private
     */
    _getTemplate: function (templateUrl) {

        var self = this;

        if (this.templateCache.hasOwnProperty(templateUrl)) {
            var promise = new BX.Promise();
            promise.fulfill(this.templateCache[templateUrl]);
            return promise;
        }

        return BX.ajax.promise({
            url: templateUrl
        }).then(function (template) {
            self.templateCache[templateUrl] = template;
            return template;
        });
    },

    /**
     * Возвращает шаблон Mustache по указанному id.
     * @param {string} id Идентификатор тега script с шаблоном на странице.
     * @return {string}
     * @private
     */
    _getTemplateFromPage: function (id) {
        return BX(id).innerHTML;
    }
};