<?php
defined('B_PROLOG_INCLUDED') || die;

use Bitrix\Main\Config\Option;
use Bitrix\Main\Loader;
use Bitrix\Main\Localization\Loc;
use Bitrix\Main\Web\Json;

/** @var CBitrixComponentTemplate $this */

if (!Loader::includeModule('crm')) {
    ShowError(Loc::getMessage('CRMSTORES_NO_CRM_MODULE'));
    return;
}

ob_start();
$APPLICATION->IncludeComponent(
    'academy.crmstores:store.bounddeals',
    '',
    array(
        'STORE_ID' => $arResult['STORE']['ID']
    ),
    $this->getComponent(),
    array('HIDE_ICONS' => 'Y')
);
$boundDealsHtml = ob_get_clean();

$tabs = array(
    array(
        'id' => 'tab_1',
        'name' => Loc::getMessage('CRMSTORES_TAB_STORE_NAME'),
        'title' => Loc::getMessage('CRMSTORES_TAB_STORE_TITLE'),
        'display' => false,
        'fields' => array(
            array(
                'id' => 'section_store',
                'name' => Loc::getMessage('CRMSTORES_FIELD_SECTION_STORE'),
                'type' => 'section',
                'isTactile' => true,
            ),
            array(
                'id' => 'ID',
                'name' => Loc::getMessage('CRMSTORES_FIELD_ID'),
                'type' => 'label',
                'value' => $arResult['STORE']['ID'],
                'isTactile' => true,
            ),
            array(
                'id' => 'NAME',
                'name' => Loc::getMessage('CRMSTORES_FIELD_NAME'),
                'type' => 'label',
                'value' => $arResult['STORE']['NAME'],
                'isTactile' => true,
            ),
            array(
                'id' => 'ADDRESS',
                'name' => Loc::getMessage('CRMSTORES_FIELD_ADDRESS'),
                'type' => 'label',
                'value' => $arResult['STORE']['ADDRESS'],
                'isTactile' => true,
            ),
            array(
                'id' => 'ASSIGNED_BY',
                'name' => Loc::getMessage('CRMSTORES_FIELD_ASSIGNED_BY'),
                'type' => 'custom',
                'value' => CCrmViewHelper::PrepareFormResponsible(
                    $arResult['STORE']['ASSIGNED_BY_ID'],
                    CSite::GetNameFormat(),
                    Option::get('intranet', 'path_user', '', SITE_ID) . '/'
                ),
                'isTactile' => true,
            )
        )
    ),
    array(
        'id' => 'deals',
        'name' => Loc::getMessage('CRMSTORES_TAB_DEALS_NAME'),
        'title' => Loc::getMessage('CRMSTORES_TAB_DEALS_TITLE'),
        'fields' => array(
            array(
                'id' => 'DEALS',
                'colspan' => true,
                'type' => 'custom',
                'value' => $boundDealsHtml
            )
        )
    )
);

if (!empty($arResult['BIZPROC_TAB'])) {
    $tabs[] = array(
        'id' => $arResult['BIZPROC_TAB']['ID'],
        'name' => Loc::getMessage('CRMSTORES_TAB_BP_NAME'),
        'title' => Loc::getMessage('CRMSTORES_TAB_BP_TITLE'),
        'fields' => array(
            array(
                'id' => 'WORKFLOW_VIEW',
                'colspan' => true,
                'type' => 'custom',
                'value' => $arResult['BIZPROC_TAB']['HTML']
            )
        )
    );
}

foreach ($arResult['PLACEMENTS'] as $placementHandler) {

    $tabId = 'tab_rest_' . $placementHandler['ID'];
    $wrapperId = 'placement_' . $placementHandler['ID'] . '_wrapper';
    $serviceUrl = '/bitrix/components/bitrix/app.layout/lazyload.ajax.php?&site=' . SITE_ID . '&' . bitrix_sessid_get();
    $loaderId = strtolower($arParams['FORM_ID'] . '_' . $tabId);
    $componentData = array(
        'template' => '',
        'params' => array(
            'PLACEMENT' => 'CRM_STORE_DETAILS',
            'PLACEMENT_OPTIONS' => array(
                'ID' => $arResult['STORE']['ID'],
            ),
            'ID' => $placementHandler['APP_ID'],
            'PLACEMENT_ID' => $placementHandler['ID'],
        ),
    );

    $tabs[] = array(
        'id' => $tabId,
        'name' => strlen($placementHandler['TITLE']) > 0
            ? $placementHandler['TITLE']
            : $placementHandler['APP_NAME'],
        'fields' => array(
            array(
                'id' => $tabId,
                'colspan' => true,
                'type' => 'custom',
                'value' => '<div id="' . $wrapperId . '"></div>'
            )
        ),
    );

    ?>
    <script>
        BX.ready(function () {
            BX.CrmFormTabLazyLoader.create(
                <?= Json::encode($loaderId) ?>,
                <?= Json::encode(array(
                    'containerID' => $wrapperId,
                    'serviceUrl' => $serviceUrl,
                    'formID' => $arResult['FORM_ID'],
                    'tabID' => $tabId,
                    'params' => $componentData,
                )) ?>
            );
        });
    </script>
    <?
}

$APPLICATION->IncludeComponent(
    'bitrix:crm.interface.form',
    'show',
    array(
        'GRID_ID' => $arResult['GRID_ID'],
        'FORM_ID' => $arResult['FORM_ID'],
        'TACTILE_FORM_ID' => $arResult['TACTILE_FORM_ID'],
        'ENABLE_TACTILE_INTERFACE' => 'Y',
        'SHOW_SETTINGS' => 'Y',
        'DATA' => $arResult['STORE'],
        'TABS' => $tabs,
    ),
    $this->getComponent(),
    array('HIDE_ICONS' => 'Y')
);